==> 4.5.0.tar.gz: terraform-provider-decort/internal/service/cloudbroker/grid/utility_grid_get_post_diagnosis.go <==
/*
Copyright (c) 2019-2023 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Sergey Kisil, <svkisil@digitalenergy.online>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort   

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package grid

import (
	"context"
	"strconv"

	log "github.com/sirupsen/logrus"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudbroker/grid"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"

	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
)

func utilityGridGetDiagnosisCheckPresence(ctx context.Context, d *schema.ResourceData, m interface{}) (string, error) {
	c := m.(*controller.ControllerCfg)
	req := grid.GetDiagnosisRequest{}

	if d.Id() != "" {
		id, _ := strconv.ParseUint(d.Id(), 10, 64)
		req.GID = id
	} else {
		req.GID = uint64(d.Get("gid").(int))
	}

	log.Debugf("utilityGridListConsumptionCheckPresence: load grid list consumption")
	gridGetDiagnosis, err := c.CloudBroker().Grid().GetDiagnosisGET(ctx, req)
	if err != nil {
		return "", err
	}

	return gridGetDiagnosis, nil
}

func utilityGridPostDiagnosisCheckPresence(ctx context.Context, d *schema.ResourceData, m interface{}) (string, error) {
	c := m.(*controller.ControllerCfg)
	req := grid.GetDiagnosisRequest{}

	if d.Id() != "" {
		id, _ := strconv.ParseUint(d.Id(), 10, 64)
		req.GID = id
	} else {
		req.GID = uint64(d.Get("gid").(int))
	}
	
	log.Debugf("utilityGridListConsumptionCheckPresence: load grid list consumption")
	gridPostDiagnosis, err := c.CloudBroker().Grid().GetDiagnosis(ctx, req)
	if err != nil {
		return "", err
	}

	return gridPostDiagnosis, nil
}

==> 4.7.4.tar.gz: terraform-provider-decort/internal/service/cloudbroker/grid/utility_grid_get_post_diagnosis.go <==
/*
Copyright (c) 2019-2023 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Sergey Kisil, <svkisil@digitalenergy.online>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package grid

import (
	"context"
	"strconv"

	log "github.com/sirupsen/logrus"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudbroker/grid"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"

	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
)

func utilityGridGetDiagnosisCheckPresence(ctx context.Context, d *schema.ResourceData, m interface{}) (string, error) {
	c := m.(*controller.ControllerCfg)
	req := grid.GetDiagnosisRequest{}

	if d.Id() != "" {
		id, _ := strconv.ParseUint(d.Id(), 10, 64)
		req.GID = id
	} else {
		req.GID = uint64(d.Get("gid").(int))
	}

	log.Debugf("utilityGridGetDiagnosisCheckPresence: load grid get diagnosis")
	gridGetDiagnosis, err := c.CloudBroker().Grid().GetDiagnosisGET(ctx, req)
	if err != nil {
		return "", err
	}

	return gridGetDiagnosis, nil
}

func utilityGridPostDiagnosisCheckPresence(ctx context.Context, d *schema.ResourceData, m interface{}) (string, error) {
	c := m.(*controller.ControllerCfg)
	req := grid.GetDiagnosisRequest{}

	if d.Id() != "" {
		id, _ := strconv.ParseUint(d.Id(), 10, 64)
		req.GID = id
	} else {
		req.GID = uint64(d.Get("gid").(int))
	}

	log.Debugf("utilityGridPostDiagnosisCheckPresence: load grid post diagnosis")
	gridPostDiagnosis, err := c.CloudBroker().Grid().GetDiagnosis(ctx, req)
	if err != nil {
		return "", err
	}

	return gridPostDiagnosis, nil
}
